==> kikuchipy-0.5.4.tar.gz: kikuchipy-0.5.4/README.md <==
<div align="center">
  <a href="https://kikuchipy.org">
    <img width="60%" src="https://raw.githubusercontent.com/pyxem/kikuchipy/develop/doc/_static/logo/plasma_banner.png">
  </a>
</div>

kikuchipy is an open-source Python library for processing and analysis of electron
backscatter diffraction (EBSD) patterns. The library builds on the tools for
multi-dimensional data analysis provided by the HyperSpy library.

[![Launch binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/pyxem/kikuchipy/HEAD)
[![Gitter chat](https://badges.gitter.im/Join%20Chat.svg)](https://gitter.im/pyxem/kikuchipy)
[![Documentation status](https://readthedocs.org/projects/kikuchipy/badge/?version=latest)](https://kikuchipy.org/en/latest/)
[![Build status](https://github.com/pyxem/kikuchipy/workflows/build/badge.svg)](https://github.com/pyxem/kikuchipy/actions)
[![Coverage status](https://coveralls.io/repos/github/pyxem/kikuchipy/badge.svg?branch=develop)](https://coveralls.io/github/pyxem/kikuchipy?branch=develop)
[![PyPI version](https://img.shields.io/pypi/v/kikuchipy.svg)](https://pypi.python.org/pypi/kikuchipy)
[![Downloads per month](https://pepy.tech/badge/kikuchipy/month)](https://pepy.tech/project/kikuchipy)
[![Zenodo DOI](https://zenodo.org/badge/doi/10.5281/zenodo.3597646.svg)](https://doi.org/10.5281/zenodo.3597646)
[![All Contributors](https://img.shields.io/badge/contributors-5-b1aee3.svg)](#contributors-)

- **User guide and API reference**: https://kikuchipy.org. The guide consists of Jupyter
  Notebooks with many links to detailed explanations of the input parameters and output
  of functions and class methods (the API reference). The notebooks can be inspected
  statically on the web page or via `nbviewer`, downloaded and run locally, or run
  interactively in the browser after clicking the Binder link above and navigating to
  the `doc/user_guide` directory. We hope you find them useful!
- **License**: kikuchipy is released under the GPLv3+ license.
- **Cite**: If you find this project useful, please cite the DOI above.
- **Changelog**: The library is in an alpha stage, so there will be breaking changes
  with each release. Please see
  [the changelog](https://kikuchipy.org/en/latest/changelog.html) for all developments.

## Contributors ✨

Thanks goes to these wonderful people ([emoji key](https://allcontributors.org/docs/en/emoji-key)):

<!-- ALL-CONTRIBUTORS-LIST:START - Do not remove or modify this section -->
<!-- prettier-ignore-start -->
<!-- markdownlint-disable -->
<table>
  <tr>
    <td align="center"><a href="https://github.com/ericpre"><img src="https://avatars.githubusercontent.com/u/11851990?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Eric Prestat</b></sub></a><br /><a href="https://github.com/pyxem/kikuchipy/commits?author=ericpre" title="Code">💻</a> <a href="#maintenance-ericpre" title="Maintenance">🚧</a></td>
    <td align="center"><a href="https://www.ntnu.edu/employees/hakon.w.anes"><img src="https://avatars.githubusercontent.com/u/12139781?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Håkon Wiik Ånes</b></sub></a><br /></td>
    <td align="center"><a href="https://github.com/friedkitteh"><img src="https://avatars.githubusercontent.com/u/11888052?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Lars Lervik</b></sub></a><br /><a href="https://github.com/pyxem/kikuchipy/issues?q=author%3Afriedkitteh" title="Bug reports">🐛</a> <a href="https://github.com/pyxem/kikuchipy/commits?author=friedkitteh" title="Code">💻</a> <a href="https://github.com/pyxem/kikuchipy/commits?author=friedkitteh" title="Documentation">📖</a> <a href="#question-friedkitteh" title="Answering Questions">💬</a> <a href="https://github.com/pyxem/kikuchipy/pulls?q=is%3Apr+reviewed-by%3Afriedkitteh" title="Reviewed Pull Requests">👀</a> <a href="https://github.com/pyxem/kikuchipy/commits?author=friedkitteh" title="Tests">⚠️</a></td>
    <td align="center"><a href="https://github.com/onatlandsmyr"><img src="https://avatars.githubusercontent.com/u/34620114?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Ole Natlandsmyr</b></sub></a><br /><a href="https://github.com/pyxem/kikuchipy/commits?author=onatlandsmyr" title="Code">💻</a> <a href="https://github.com/pyxem/kikuchipy/commits?author=onatlandsmyr" title="Documentation">📖</a> <a href="#question-onatlandsmyr" title="Answering Questions">💬</a> <a href="https://github.com/pyxem/kikuchipy/pulls?q=is%3Apr+reviewed-by%3Aonatlandsmyr" title="Reviewed Pull Requests">👀</a> <a href="https://github.com/pyxem/kikuchipy/commits?author=onatlandsmyr" title="Tests">⚠️</a></td>
    <td align="center"><a href="https://github.com/tinabe"><img src="https://avatars.githubusercontent.com/u/22915119?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Tina Bergh</b></sub></a><br /><a href="https://github.com/pyxem/kikuchipy/commits?author=tinabe" title="Code">💻</a> <a href="https://github.com/pyxem/kikuchipy/pulls?q=is%3Apr+reviewed-by%3Atinabe" title="Reviewed Pull Requests">👀</a></td>
    <td align="center"><a href="https://github.com/IMBalENce"><img src="https://avatars.githubusercontent.com/u/2986794?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Zhou Xu</b></sub></a><br /><a href="https://github.com/pyxem/kikuchipy/issues?q=author%3AIMBalENce" title="Bug reports">🐛</a> <a href="https://github.com/pyxem/kikuchipy/commits?author=IMBalENce" title="Code">💻</a> <a href="https://github.com/pyxem/kikuchipy/commits?author=IMBalENce" title="Documentation">📖</a> <a href="https://github.com/pyxem/kikuchipy/commits?author=IMBalENce" title="Tests">⚠️</a></td>
  </tr>
</table>

<!-- markdownlint-restore -->
<!-- prettier-ignore-end -->

<!-- ALL-CONTRIBUTORS-LIST:END -->

This project follows the [all-contributors](https://github.com/all-contributors/all-contributors) specification.
Contributions of any kind welcome! Please see our
[contributing guide](https://kikuchipy.org/en/latest/contributing.html) for further
information on how best to contribute.

==> kikuchipy-0.5.6.tar.gz: kikuchipy-0.5.6/README.md <==
<div align="center">
  <a href="https://kikuchipy.org">
    <img width="60%" src="https://raw.githubusercontent.com/pyxem/kikuchipy/develop/doc/_static/logo/plasma_banner.png">
  </a>
</div>

kikuchipy [ki-ko-chi-pai] is an open-source Python library for processing and analysis
of electron backscatter diffraction (EBSD) patterns. The library builds on the tools for
multi-dimensional data analysis provided by the HyperSpy library.

[![Launch binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/pyxem/kikuchipy/HEAD)
[![Gitter chat](https://badges.gitter.im/Join%20Chat.svg)](https://gitter.im/pyxem/kikuchipy)
[![Documentation status](https://readthedocs.org/projects/kikuchipy/badge/?version=latest)](https://kikuchipy.org/en/latest/)
[![Build status](https://github.com/pyxem/kikuchipy/workflows/build/badge.svg)](https://github.com/pyxem/kikuchipy/actions)
[![Coverage status](https://coveralls.io/repos/github/pyxem/kikuchipy/badge.svg?branch=develop)](https://coveralls.io/github/pyxem/kikuchipy?branch=develop)
[![PyPI version](https://img.shields.io/pypi/v/kikuchipy.svg)](https://pypi.python.org/pypi/kikuchipy)
[![Downloads per month](https://pepy.tech/badge/kikuchipy/month)](https://pepy.tech/project/kikuchipy)
[![Zenodo DOI](https://zenodo.org/badge/doi/10.5281/zenodo.3597646.svg)](https://doi.org/10.5281/zenodo.3597646)
[![All Contributors](https://img.shields.io/badge/contributors-5-b1aee3.svg)](#contributors-)

- **User guide and API reference**: https://kikuchipy.org. The guide consists of Jupyter
  Notebooks with many links to detailed explanations of the input parameters and output
  of functions and class methods (the API reference). The notebooks can be inspected
  statically on the web page or via `nbviewer`, downloaded and run locally, or run
  interactively in the browser after clicking the Binder link above and navigating to
  the `doc/user_guide` directory. We hope you find them useful!
- **License**: kikuchipy is released under the GPLv3+ license.
- **Cite**: If you find this project useful, please cite the DOI above.
- **Changelog**: The library is in continuous development (alpha stage), so expect some
  breaking changes with each release. Please see
  [the changelog](https://kikuchipy.org/en/latest/changelog.html) for all developments.

## Contributors ✨

Thanks goes to these wonderful people ([emoji key](https://allcontributors.org/docs/en/emoji-key)):

<!-- ALL-CONTRIBUTORS-LIST:START - Do not remove or modify this section -->
<!-- prettier-ignore-start -->
<!-- markdownlint-disable -->
<table>
  <tr>
    <td align="center"><a href="https://github.com/ericpre"><img src="https://avatars.githubusercontent.com/u/11851990?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Eric Prestat</b></sub></a><br /><a href="https://github.com/pyxem/kikuchipy/commits?author=ericpre" title="Code">💻</a> <a href="#maintenance-ericpre" title="Maintenance">🚧</a></td>
    <td align="center"><a href="https://www.ntnu.edu/employees/hakon.w.anes"><img src="https://avatars.githubusercontent.com/u/12139781?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Håkon Wiik Ånes</b></sub></a><br /></td>
    <td align="center"><a href="https://github.com/friedkitteh"><img src="https://avatars.githubusercontent.com/u/11888052?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Lars Lervik</b></sub></a><br /><a href="https://github.com/pyxem/kikuchipy/issues?q=author%3Afriedkitteh" title="Bug reports">🐛</a> <a href="https://github.com/pyxem/kikuchipy/commits?author=friedkitteh" title="Code">💻</a> <a href="https://github.com/pyxem/kikuchipy/commits?author=friedkitteh" title="Documentation">📖</a> <a href="#question-friedkitteh" title="Answering Questions">💬</a> <a href="https://github.com/pyxem/kikuchipy/pulls?q=is%3Apr+reviewed-by%3Afriedkitteh" title="Reviewed Pull Requests">👀</a> <a href="https://github.com/pyxem/kikuchipy/commits?author=friedkitteh" title="Tests">⚠️</a></td>
    <td align="center"><a href="https://github.com/onatlandsmyr"><img src="https://avatars.githubusercontent.com/u/34620114?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Ole Natlandsmyr</b></sub></a><br /><a href="https://github.com/pyxem/kikuchipy/commits?author=onatlandsmyr" title="Code">💻</a> <a href="https://github.com/pyxem/kikuchipy/commits?author=onatlandsmyr" title="Documentation">📖</a> <a href="#question-onatlandsmyr" title="Answering Questions">💬</a> <a href="https://github.com/pyxem/kikuchipy/pulls?q=is%3Apr+reviewed-by%3Aonatlandsmyr" title="Reviewed Pull Requests">👀</a> <a href="https://github.com/pyxem/kikuchipy/commits?author=onatlandsmyr" title="Tests">⚠️</a></td>
    <td align="center"><a href="https://github.com/tinabe"><img src="https://avatars.githubusercontent.com/u/22915119?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Tina Bergh</b></sub></a><br /><a href="https://github.com/pyxem/kikuchipy/commits?author=tinabe" title="Code">💻</a> <a href="https://github.com/pyxem/kikuchipy/pulls?q=is%3Apr+reviewed-by%3Atinabe" title="Reviewed Pull Requests">👀</a></td>
    <td align="center"><a href="https://github.com/IMBalENce"><img src="https://avatars.githubusercontent.com/u/2986794?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Zhou Xu</b></sub></a><br /><a href="https://github.com/pyxem/kikuchipy/issues?q=author%3AIMBalENce" title="Bug reports">🐛</a> <a href="https://github.com/pyxem/kikuchipy/commits?author=IMBalENce" title="Code">💻</a> <a href="https://github.com/pyxem/kikuchipy/commits?author=IMBalENce" title="Documentation">📖</a> <a href="https://github.com/pyxem/kikuchipy/commits?author=IMBalENce" title="Tests">⚠️</a></td>
  </tr>
</table>

<!-- markdownlint-restore -->
<!-- prettier-ignore-end -->

<!-- ALL-CONTRIBUTORS-LIST:END -->

This project follows the [all-contributors](https://github.com/all-contributors/all-contributors) specification.
Contributions of any kind welcome! Please see our
[contributing guide](https://kikuchipy.org/en/latest/contributing.html) for further
information on how best to contribute.
